Rename MediaReceiveStream to MediaReceiveStreamInterface

Bug: webrtc:7484
Change-Id: I0bc4bc57e8c4450c503ae4d5a41f9bbe243b00e6
Reviewed-on: https://webrtc-review.googlesource.com/c/src/+/262768
Commit-Queue: Tomas Gunnarsson <tommi@webrtc.org>
Reviewed-by: Niels Moller <nisse@webrtc.org>
Cr-Commit-Position: refs/heads/main@{#36947}
diff --git a/call/receive_stream.h b/call/receive_stream.h
index 4a946d6..f24c045 100644
--- a/call/receive_stream.h
+++ b/call/receive_stream.h
@@ -22,7 +22,7 @@
 
 namespace webrtc {
 
 // Common base interface for MediaReceiveStream based classes and
 // FlexfecReceiveStream.
 class ReceiveStreamInterface {
  public:
@@ -72,7 +72,7 @@
 };
 
 // Either an audio or video receive stream.
-class MediaReceiveStream : public ReceiveStreamInterface {
+class MediaReceiveStreamInterface : public ReceiveStreamInterface {
  public:
   // Starts stream activity.
   // When a stream is active, it can receive, process and deliver packets.
@@ -22,7 +22,7 @@
 namespace webrtc {
 
-// Common base interface for MediaReceiveStream based classes and
+// Common base interface for MediaReceiveStreamInterface based classes and
 // FlexfecReceiveStream.
 class ReceiveStreamInterface {